@@ -25,9 +25,10 @@
 
 // application specific includes
 #include "dbids.h"
-#include "calcpart.h"
 #include "attribute.h"
 #include "einheit.h"
+#include "geld.h"
+#include "kraftobj.h"
 
 /**
 @author Klaas Freitag
@@ -40,71 +41,44 @@ class dbID;
 class QLocale;
 class PositionViewWidget;
 
-class DocPositionBase : public QObject
+class DocPosition : public KraftObj
 {
-  public:
-  enum PositionType { Position, ExtraDiscount };
-  enum TaxType { TaxInvalid = 0, TaxNone = 1, TaxReduced = 2, TaxFull = 3, TaxIndividual = 4 };
 
-    DocPositionBase();
-    DocPositionBase( const PositionType& );
-    ~DocPositionBase() {}
+public:
+    enum class Type { Position, ExtraDiscount, Text, Demand, Alternative };
+    enum class Tax { Invalid = 0, None = 1, Reduced = 2, Full = 3, Individual = 4 };
 
-    DocPositionBase(const DocPositionBase&);
+    static const QString Kind;
+    static const QString Discount;
+    static const QString Tags;
+    static const QString ExtraDiscountTagRequired;
+
+    DocPosition();
+    DocPosition( const Type& );
 
     void setDbId( int id ) { m_dbId = id; }
     dbID dbId() { return dbID( m_dbId ); }
 
-    void setAttribute( const Attribute& );
-    void removeAttribute( const QString& );
-    void loadAttributes();
-    QString attribute(const QString& ) const;
-
-    AttributeMap attributes();
-    void setAttributeMap( AttributeMap );
-
     void setText( const QString& string ) { m_text = string; }
     QString text() const { return m_text; }
-
-    void replaceTags(const QStringList& newTags);
-    void setTag( const QString& );
-    void removeTag( const QString& );
-    bool hasTag( const QString& );
-
-    QStringList tags();
     
     int taxTypeNumeric();
-    TaxType taxType();
-    void setTaxType( DocPositionBase::TaxType );
+    Tax taxType();
+    void setTaxType( DocPosition::Tax );
     void setTaxType( int );
+    void setTaxType(const QString&);
 
-  /**
+    /**
    * Position means the number in the document
    */
     int positionNumber() { return m_position; }
     void setPositionNumber( const int& pos ) { m_position = pos; }
     void setToDelete( bool doit ) { mToDelete = doit; }
     bool toDelete() { return mToDelete; }
-    PositionType type() { return mType; }
-
-    DocPositionBase& operator=( const DocPositionBase& );
-
-  protected:
-    int     m_dbId;
-    int     m_position;
-    QString m_text;
-    bool    mToDelete;
-    TaxType mTaxType;
-    PositionType mType;
-    AttributeMap mAttribs;
-};
-
-
-class DocPosition : public DocPositionBase
-{
-  public:
-    DocPosition();
-    DocPosition( const PositionType& );
+    Type type() { return mType; }
+    QString typeStr();
+    static QString typeToString(Type t);
+    static Type typeStrToType(const QString& t);
 
     void setUnit( const Einheit& unit ) { m_unit = unit; }
     Einheit unit() const { return m_unit; }
@@ -115,33 +89,33 @@ class DocPosition : public DocPositionBase
 
     void setAmount( double amount ) { m_amount = amount; }
     double amount() { return m_amount; }
-    
+
     PositionViewWidget* associatedWidget() { return mWidget; }
     void setAssociatedWidget( PositionViewWidget *w ) { mWidget = w; }
 
-    static const QString Kind;
-    static const QString Discount;
-    static const QString Tags;
-    static const QString ExtraDiscountTagRequired;
+private:
+    int     m_dbId;
+    int     m_position;
+    QString m_text;
+    bool    mToDelete;
+    Tax     mTaxType;
+    Type    mType;
 
-  private:
     Einheit m_unit;
     Geld    m_unitPrice;
     double  m_amount;
     PositionViewWidget *mWidget;
-
-    // No calculation yet
-
 };
 
-class DocPositionList : public QList<DocPositionBase*>
+
+class DocPositionList : public QList<DocPosition*>
 {
-  public:
+public:
     DocPositionList();
 
     // QDomElement domElement( QDomDocument& );
-    DocPositionBase *positionFromId( int id );
-    QString posNumber( DocPositionBase* );
+    DocPosition *positionFromId( int id );
+    QString posNumber( DocPosition* );
 
     Geld nettoPrice();
     Geld bruttoPrice( double fullTax, double reducedTax );
@@ -149,14 +123,21 @@ class DocPositionList : public QList<DocPositionBase*>
     Geld fullTaxSum( double fullTax );
     Geld reducedTaxSum( double reducedTax );
 
-  protected:
+    DocPosition::Tax  listTaxation() const;
+    bool hasIndividualTaxes() const;
+
+protected:
     int compareItems ( DocPosition *dp1, DocPosition *dp2 );
 
-  private:
+private:
     QDomElement xmlTextElement( QDomDocument&, const QString& , const QString& );
 };
 
-typedef QListIterator<DocPositionBase*> DocPositionListIterator;
+typedef QListIterator<DocPosition*> DocPositionListIterator;
+
+typedef DocPosition* DocPositionGuardedPtr;
+
+Q_DECLARE_METATYPE(DocPosition)
+Q_DECLARE_METATYPE(DocPositionList)
 
-typedef QPointer<DocPositionBase> DocPositionGuardedPtr;
 #endif
