@@ -21,13 +21,13 @@
 #include <QPushButton>
 #include <QComboBox>
 #include <QCheckBox>
-#include <QSqlQuery>
 #include <QSpinBox>
 #include <QListWidget>
 #include <QLocale>
 #include <QIcon>
 #include <QMessageBox>
 #include <QInputDialog>
+#include <QSqlQuery>
 
 #include <QDialog>
 #include <QDebug>
@@ -117,27 +117,18 @@ DocTypeEdit::DocTypeEdit( QWidget *parent )
 
   connect( mCbXRechnung, &QCheckBox::toggled, this, &DocTypeEdit::slotXRechnungToggled);
 
-  connect( mPbAdd, SIGNAL( clicked() ),
-           SLOT( slotAddDocType() ) );
-  connect( mPbEdit, SIGNAL( clicked() ),
-           SLOT( slotEditDocType() ) );
-  connect( mPbRemove, SIGNAL( clicked() ),
-           SLOT( slotRemoveDocType() ) );
+  connect( mPbAdd, &QPushButton::clicked, this, &DocTypeEdit::slotAddDocType);
+  connect( mPbEdit, &QPushButton::clicked, this, &DocTypeEdit::slotEditDocType);
+  connect( mPbRemove, &QPushButton::clicked, this, &DocTypeEdit::slotRemoveDocType);
 
-  connect( mNumberCycleCombo, SIGNAL( activated( const QString& ) ),
-           SLOT( slotNumberCycleChanged( const QString& ) ) );
+  connect(mNumberCycleCombo, &QComboBox::currentTextChanged, this, &DocTypeEdit::slotNumberCycleChanged);
 
-  connect( mPbEditCycles, SIGNAL( clicked() ),
-           SLOT( slotEditNumberCycles() ) );
+  connect( mPbEditCycles, &QPushButton::clicked, this, &DocTypeEdit::slotEditNumberCycles);
 
-  connect( mWatermarkCombo, SIGNAL( activated( int ) ),
-           SLOT( slotWatermarkModeChanged( int ) ) );
+  connect( mWatermarkCombo, &QComboBox::activated, this, &DocTypeEdit::slotWatermarkModeChanged);
 
-  connect( mWatermarkUrl, SIGNAL( textChanged( const QString& ) ),
-           SLOT( slotWatermarkUrlChanged( const QString& ) ) );
-
-  connect( mTemplateUrl, SIGNAL( textChanged( const QString& ) ),
-           SLOT( slotTemplateUrlChanged( const QString& ) ) );
+  connect( mWatermarkUrl, &QLineEdit::textChanged, this, &DocTypeEdit::slotWatermarkUrlChanged);
+  connect( mTemplateUrl, &QLineEdit::textChanged, this, &DocTypeEdit::slotTemplateUrlChanged);
 
   connect( mAppendUrl, &QLineEdit::textChanged, this, &DocTypeEdit::slotAppendPDFUrlChanged );
 
@@ -158,15 +149,11 @@ DocTypeEdit::DocTypeEdit( QWidget *parent )
 
 void DocTypeEdit::fillNumberCycleCombo()
 {
-  QSqlQuery q;
-  q.prepare( "SELECT name FROM numberCycles ORDER BY name" );
-  q.exec();
-  QStringList cycles;
-  while ( q.next() ) {
-    cycles << q.value( 0 ).toString();
-  }
+  QMap<QString, NumberCycle> ncs = NumberCycles::load();
+
+  const QStringList cycles = ncs.keys();
   mNumberCycleCombo->clear();
-  mNumberCycleCombo->insertItems(-1, cycles );
+  mNumberCycleCombo->addItems(cycles);
 }
 
 void DocTypeEdit::slotAddDocType()
@@ -280,7 +267,7 @@ void DocTypeEdit::slotRemoveDocType()
 
   delete currItem;
   // qDebug () << "removed type: " << mRemovedTypes;
-  emit removedType( currName );
+  Q_EMIT removedType( currName );
 }
 
 void DocTypeEdit::slotDocTypeSelected( const QString& newValue )
@@ -299,7 +286,10 @@ void DocTypeEdit::slotDocTypeSelected( const QString& newValue )
     prevType = mChangedDocTypes[mPreviousType];
     // qDebug () << "previous docType taken from ChangedDocTypes: ";
   }
-  prevType.setNumberCycleName( mNumberCycleCombo->currentText() );
+  const QString oldNcName = prevType.numberCycleName();
+  const NumberCycle oldNc = NumberCycles::get(oldNcName);
+
+  prevType.setNumberCycleName(oldNcName);
   prevType.setTemplateFile( mTemplateUrl->text() );
   prevType.setWatermarkFile( mWatermarkUrl->text() );
   prevType.setAppendPDFFile(mAppendUrl->text());
@@ -307,16 +297,19 @@ void DocTypeEdit::slotDocTypeSelected( const QString& newValue )
   prevType.setXRechnungEnabled(mCbXRechnung->checkState() == Qt::Checked);
   mChangedDocTypes[mPreviousType] = prevType;
 
-  // dt.setNumberCycleName( dt.numberCycleName() );
-  // qDebug () << "Selected doc type " << newValue;
-  mIdent->setText( dt.identTemplate() );
-  int nextNum = dt.nextIdentId( false )-1;
-  mCounter->setText( QString::number( nextNum ) );
+  qDebug () << "Selected doc type " << newValue;
+  const QString& ncn = dt.numberCycleName();
+  NumberCycle nc = NumberCycles::get(ncn);
+
+  mIdent->setText(nc.getTemplate());
+  const QString nextNum = nc.exampleIdent(dt.name(), QDate::currentDate(), QStringLiteral("<addressId>"));
+  mCounter->setText(nextNum);
   mNumberCycleCombo->setCurrentIndex(mNumberCycleCombo->findText( dt.numberCycleName() ));
   // mHeader->setText( i18n( "Details for %1:", dt.name() ) );
-  mExampleId->setText( dt.generateDocumentIdent( QDate::currentDate(),
-                                                 mExampleAddressUid,
-                                                 nextNum, 2 /* phantasie date counter */) );
+
+  mExampleId->setText( nc.exampleIdent(newValue,
+                                       QDate::currentDate(),
+                                       mExampleAddressUid) );
 
   mTemplateUrl->setText( dt.templateFile() );
 
@@ -341,15 +334,16 @@ void DocTypeEdit::slotEditNumberCycles()
   if ( dia.exec() == QDialog::Accepted ) {
     fillNumberCycleCombo();
     mNumberCycleCombo->setCurrentIndex(mNumberCycleCombo->findText( currNumbercycle ));
+    NumberCycle nc = NumberCycles::get(currNumbercycle);
 
-    DocType dt = currentDocType();
-    dt.readIdentTemplate();
     // only the numbercycle has changed - refresh the display
-    mIdent->setText( dt.identTemplate() );
-    int nextNum = dt.nextIdentId( false )-1;
+    mIdent->setText(nc.getTemplate());
+    int nextNum = nc.counter();
     mCounter->setText( QString::number( nextNum ) );
-    mExampleId->setText( dt.generateDocumentIdent( QDate::currentDate(),
-                                                   mExampleAddressUid, nextNum, 2 ) );
+    const QString docType = mTypeListBox->currentItem()->text();
+    mExampleId->setText( nc.exampleIdent( docType,
+                                          QDate::currentDate(),
+                                          mExampleAddressUid) );
   }
 }
 
@@ -434,32 +428,19 @@ void DocTypeEdit::slotWatermarkUrlChanged( const QString& newUrl )
 
 void DocTypeEdit::slotNumberCycleChanged( const QString& newCycle )
 {
-  QString docTypeName = mTypeListBox->currentItem()->text();
   DocType dt = currentDocType();
   dt.setNumberCycleName( newCycle );
-  mChangedDocTypes[docTypeName] = dt;
+  mChangedDocTypes[newCycle] = dt;
+
+  NumberCycle nc = NumberCycles::get(newCycle);
   // qDebug () << "Changing the cycle name of " << docTypeName << " to " << newCycle;
 
-  mIdent->setText( dt.identTemplate() );
-  int nextNum = dt.nextIdentId( false )-1;
+  mIdent->setText( nc.getTemplate() );
+  int nextNum = nc.counter();
   mCounter->setText( QString::number( nextNum ) );
-  mExampleId->setText( dt.generateDocumentIdent( QDate::currentDate(),
-                                                 mExampleAddressUid, nextNum, 2 ) );
-}
-
-QStringList DocTypeEdit::allNumberCycles()
-{
-  QStringList re;
-  re << NumberCycle::defaultName();
-  QSqlQuery q( "SELECT av.value FROM attributes a, attributeValues av "
-               "WHERE a.id=av.attributeId AND a.hostObject='DocType' "
-               "AND a.name='identNumberCycle'" );
-
-  while ( q.next() ) {
-    QString cycleName = q.value(0).toString();
-    re << cycleName;
-  }
-  return re;
+  mExampleId->setText( nc.exampleIdent(newCycle,
+                                       QDate::currentDate(),
+                                       mExampleAddressUid) );
 }
 
 void DocTypeEdit::saveDocTypes()
@@ -472,7 +453,7 @@ void DocTypeEdit::saveDocTypes()
       removeTypeFromDb( *it );
       mOrigDocTypes.remove( *it );
       mChangedDocTypes.remove( *it );
-      emit removedType( *it );
+      Q_EMIT removedType( *it );
     }
   }
 
