@@ -23,11 +23,12 @@
 
 #include "documentman.h"
 #include "defaultprovider.h"
-#include "docdigest.h"
-#include "kraftdb.h"
 #include "doctype.h"
 #include "kraftsettings.h"
 
+#include "defaultprovider.h"
+#include "documentsaverxml.h"
+
 Q_GLOBAL_STATIC(DocumentMan, mSelf)
 
 DocumentMan *DocumentMan::self()
@@ -36,35 +37,34 @@ DocumentMan *DocumentMan::self()
 }
 
 DocumentMan::DocumentMan()
-  : mFullTax( -1 ),
-    mReducedTax( -1 )
 {
 
 }
 
-DocGuardedPtr DocumentMan::copyDocument( const QString& copyFromId )
+DocGuardedPtr DocumentMan::copyDocument(const QString& copyFromUuid)
 {
     DocGuardedPtr doc = new KraftDoc( );
-    if ( ! copyFromId.isEmpty() ) {
+    if ( ! copyFromUuid.isEmpty() ) {
         // copy the content from the source document to the new doc.
-        DocGuardedPtr sourceDoc = openDocument( copyFromId );
+        DocGuardedPtr sourceDoc = openDocumentByUuid(copyFromUuid);
         if ( sourceDoc ) {
             *doc = *sourceDoc; // copies all data from the previous doc
             doc->setPredecessor(QString()); // clear the predecessor
+            delete sourceDoc;
         }
         doc->setLastModified( QDateTime::currentDateTime());
     }
     return doc;
 }
 
-DocGuardedPtr DocumentMan::createDocument( const QString& docType, const QString& copyFromId, const DocPositionList& listToCopy)
+DocGuardedPtr DocumentMan::createDocument( const QString& docType, const QString& copyFromUuid, const DocPositionList& listToCopy)
 {
     DocGuardedPtr doc = new KraftDoc();
     // qDebug () << "new document ID: " << doc->docID().toString();
 
-    if ( ! copyFromId.isEmpty() ) {
+    if ( ! copyFromUuid.isEmpty() ) {
         // copy the content from the source document to the new doc.
-        DocGuardedPtr sourceDoc = openDocument( copyFromId );
+        DocGuardedPtr sourceDoc = openDocumentByUuid(copyFromUuid);
         if ( sourceDoc ) {
             *doc = *sourceDoc; // copies all data from the previous doc
             doc->setIdent(QString());
@@ -74,12 +74,12 @@ DocGuardedPtr DocumentMan::createDocument( const QString& docType, const QString
 
             // check for relations between old and new doc
             DocType sourceDocType( sourceDoc->docType() );
-            // for new docs check if it should substract the sum of the predecessor doc
+            // for new docs check if it should subtract the sum of the predecessor doc
             DocType newDocType(docType);
             if( newDocType.substractPartialInvoice() ) {
                 if( sourceDocType.partialInvoice()  ) {
                     Geld g = sourceDoc->nettoSum();
-                    DocPosition *pos = doc->createPosition(DocPositionBase::Position);
+                    DocPosition *pos = doc->createPosition(DocPosition::Type::Position);
                     if(pos) {
                         Einheit e;
                         pos->setUnit(e);
@@ -87,25 +87,25 @@ DocGuardedPtr DocumentMan::createDocument( const QString& docType, const QString
                         Geld ng(-1 * g.toLong());
 
                         pos->setUnitPrice(ng);
-                        pos->setText(i18nc("Text to be inserted into a doc, if the sum of another doc needs to be substracted "
+                        pos->setText(i18nc("Text to be inserted into a doc, if the sum of another doc needs to be subtracted "
 					   "ie. in a final invoice if there was a partial invoice before"
 					   "%1 is substited by the doc type, %2 by the id of the predecessor doc.",
-					   "Substract sum from %1 %2",
-                                          sourceDocType.name(), sourceDoc->ident()));
+					   "Subtract sum from %1 %2",
+                                          sourceDocType.name(), sourceDoc->docIdentifier()));
                     }
                 }
             }
 
-            doc->setPredecessor(sourceDoc->ident());
+            doc->setPredecessor(sourceDoc->uuid());
 
             // Take the default pre- and posttext for the new docType, or, if that is empty, the texts of the old doc
-            QString newText = DefaultProvider::self()->defaultText( docType, KraftDoc::Header );
+            QString newText = DefaultProvider::self()->defaultText( docType, KraftDoc::Part::Header );
             if (newText.isEmpty() ) {
                 newText = sourceDoc->preTextRaw();
             }
             doc->setPreTextRaw(newText);
 
-            newText = DefaultProvider::self()->defaultText( docType, KraftDoc::Footer );
+            newText = DefaultProvider::self()->defaultText( docType, KraftDoc::Part::Footer );
             if (newText.isEmpty() ) {
                 newText = sourceDoc->postTextRaw();
             }
@@ -116,8 +116,8 @@ DocGuardedPtr DocumentMan::createDocument( const QString& docType, const QString
     } else {
         // Absolute new document
         doc->setDocType(docType);
-        doc->setPreTextRaw(DefaultProvider::self()->defaultText(docType, KraftDoc::Header));
-        doc->setPostTextRaw(DefaultProvider::self()->defaultText(docType, KraftDoc::Footer));
+        doc->setPreTextRaw(DefaultProvider::self()->defaultText(docType, KraftDoc::Part::Header));
+        doc->setPostTextRaw(DefaultProvider::self()->defaultText(docType, KraftDoc::Part::Footer));
         doc->setGoodbye( KraftSettings::greeting() );
     }
 
@@ -127,67 +127,51 @@ DocGuardedPtr DocumentMan::createDocument( const QString& docType, const QString
     return doc;
 }
 
-DocGuardedPtr DocumentMan::openDocumentbyIdent( const QString& ident )
+DocGuardedPtr DocumentMan::openDocumentByUuid(const QString& uuid)
 {
-    QSqlQuery q;
-    q.prepare("SELECT docID FROM document WHERE ident=:ident");
-    q.bindValue(":ident", ident);
-    q.exec();
-    if( q.next() ) {
-        const QString id = q.value(0).toString();
-        return openDocument(id);
+    // qDebug () << "Opening Document with uuid" << uuid << endl;
+    DocGuardedPtr doc = new KraftDoc();
+    if (!doc->openDocument(DefaultProvider::self()->documentPersister(), uuid)) {
+        delete doc;
+        return nullptr;
     }
-    return nullptr;
+    return doc;
 }
 
-DocGuardedPtr DocumentMan::openDocument( const QString& id )
+bool DocumentMan::loadMetaFromFilename(const QString& xmlFile, KraftDoc *doc)
 {
-  // qDebug () << "Opening Document with id " << id;
-  DocGuardedPtr doc = new KraftDoc();
-  doc->openDocument( id );
-  return doc;
+    DocumentSaverXML docLoad;
+    QFileInfo fi(xmlFile);
+
+    if (doc && docLoad.loadFromFile(fi, doc, true)) {
+        return true;
+    }
+    qDebug() << "Failed to load file" << xmlFile;
+    return false;
 }
 
-void DocumentMan::clearTaxCache()
+void DocumentMan::setDocProcessingError(const QString& errStr)
 {
-  mFullTax = -1;
-  mReducedTax = -1;
+    Q_UNUSED(errStr);
 }
 
-double DocumentMan::tax( const QDate& date )
+bool DocumentMan::saveDocument(KraftDoc* doc)
 {
-  if ( mFullTax < 0 || date != mTaxDate )
-    readTaxes( date );
-  return mFullTax;
+    if (!doc) {
+        return false;
+    }
+    bool ok = doc->saveDocument(DefaultProvider::self()->documentPersister());
+
+    return ok;
 }
 
-double DocumentMan::reducedTax( const QDate& date )
+bool DocumentMan::reloadDocument(KraftDoc* doc)
 {
-  if ( mReducedTax < 0 || date != mTaxDate )
-    readTaxes( date );
-  return mReducedTax;
-}
+    if (!doc) {
+        return false;
+    }
+    return doc->reloadDocument(DefaultProvider::self()->documentPersister());
 
-bool DocumentMan::readTaxes( const QDate& date )
-{
-  QString sql;
-  QSqlQuery q;
-  sql = "SELECT fullTax, reducedTax, startDate FROM taxes ";
-  sql += "WHERE startDate <= :date ORDER BY startDate DESC LIMIT 1";
-
-  q.prepare( sql );
-  QString dateStr = date.toString( "yyyy-MM-dd" );
-  // qDebug () << "** Datestring: " << dateStr;
-  q.bindValue( ":date", dateStr );
-  q.exec();
-
-  if ( q.next() ) {
-    mFullTax    = q.value( 0 ).toDouble();
-    mReducedTax = q.value( 1 ).toDouble();
-    mTaxDate = date;
-    // qDebug () << "* Taxes: " << mFullTax << "/" << mReducedTax << " from " << q.value( 2 ).toDate();
-  }
-  return ( mFullTax > 0 && mReducedTax > 0 );
 }
 
 DocumentMan::~DocumentMan()
