@@ -26,17 +26,24 @@
  */
 class KraftDoc;
 class dbID;
+class QAbstractItemModel;
+class DocBaseModel;
 
 class DocumentSaverBase : public QObject
 {
-  Q_OBJECT
+    Q_OBJECT
 
 public:
-  DocumentSaverBase();
-  virtual ~DocumentSaverBase();
 
-  virtual bool saveDocument( KraftDoc* ) = 0;
-  virtual void load( const QString&, KraftDoc * ) = 0;
+    DocumentSaverBase();
+    virtual ~DocumentSaverBase();
+
+    virtual bool saveDocument( KraftDoc* ) = 0;
+    virtual bool loadByIdent(const QString&, KraftDoc*) = 0;
+    virtual bool loadByUuid(const QString&, KraftDoc*) = 0;
+
+    // methods needed by the document view models
+    virtual int addDigestsToModel(DocBaseModel* model) = 0;
 };
 
 #endif
