@@ -20,7 +20,11 @@
 
 #include <kcontacts/addressee.h>
 
-#include "archdoc.h"
+namespace Template {
+    QVariantHash contactToVariantHash(const KContacts::Addressee& contact);
+    QVariantHash labelVariantHash();
+
+}
 
 class DocumentTemplate
 {
@@ -28,7 +32,7 @@ public:
     DocumentTemplate( const QString& tmplFile );
     virtual ~DocumentTemplate(){ };
 
-    virtual const QString expand(ArchDoc *archDoc,
+    virtual const QString expand(const QString& uuid,
                                  const KContacts::Addressee &myContact,
                                  const KContacts::Addressee &customerContact) = 0;
 
@@ -46,24 +50,12 @@ protected:
 
 // ==================================================================================
 
-class CTemplateDocumentTemplate : public DocumentTemplate
-{
-public:
-    CTemplateDocumentTemplate(const QString& tmplFile);
-
-    const QString expand(ArchDoc *archDoc,
-                         const KContacts::Addressee &myContact,
-                         const KContacts::Addressee &customerContact) override;
-};
-
-// ==================================================================================
-
 class GrantleeDocumentTemplate : public DocumentTemplate
 {
 public:
     GrantleeDocumentTemplate(const QString& tmplFile);
 
-    const QString expand(ArchDoc *archDoc,
+    const QString expand(const QString& uuid,
                          const KContacts::Addressee &myContact,
                          const KContacts::Addressee &customerContact) override;
 };
