@@ -30,7 +30,7 @@ class FooterTemplateProvider : public TemplateProvider
 public:
     FooterTemplateProvider( QWidget* );
 
-public slots:
+public Q_SLOTS:
     void slotNewTemplate() override;
     void slotEditTemplate() override;
     void slotDeleteTemplate() override;
@@ -38,7 +38,7 @@ public slots:
     void slotTemplateToDocument() override;
     void slotInsertTemplateToDocument() override;
 
-signals:
+Q_SIGNALS:
     void newFooterText( const DocText& );
     void updateFooterText( const DocText& );
     void footerTextToDocument(const DocText&, bool replace);
