@@ -33,10 +33,10 @@ void HeaderTemplateProvider::slotNewTemplate()
 {
   // qDebug () << "SlotNewTemplate called!";
 
-  TextEditDialog dia( mParent, KraftDoc::Header );
+  TextEditDialog dia( mParent, KraftDoc::Part::Header );
 
   DocText dt;
-  dt.setTextType( KraftDoc::Header );
+  dt.setTextType( KraftDoc::Part::Header );
   dt.setDocType( mDocType );
 
   dia.setDocText( dt );
@@ -48,7 +48,7 @@ void HeaderTemplateProvider::slotNewTemplate()
     dbID newId = DefaultProvider::self()->saveDocumentText( dt );
     dt.setDbId( newId );
 
-    emit newHeaderText( dt );
+    Q_EMIT newHeaderText( dt );
   }
 }
 
@@ -56,12 +56,12 @@ void HeaderTemplateProvider::slotEditTemplate()
 {
   // qDebug () << "SlotEditTemplate called!";
 
-  TextEditDialog dia( mParent, KraftDoc::Header );
+  TextEditDialog dia( mParent, KraftDoc::Part::Header );
 
   /* mCurrentText is set through the slot slotSetCurrentDocText */
   DocText dt = currentText();
-  if ( dt.type() == KraftDoc::Unknown ) {
-    dt.setTextType( KraftDoc::Header );
+  if ( dt.type() == KraftDoc::Part::Unknown ) {
+    dt.setTextType( KraftDoc::Part::Header );
     dt.setDocType( mDocType );
   }
 
@@ -76,7 +76,7 @@ void HeaderTemplateProvider::slotEditTemplate()
     /* save to database */
     DefaultProvider::self()->saveDocumentText( dt );
 
-    emit updateHeaderText( dt );
+    Q_EMIT updateHeaderText( dt );
   }
 
 }
@@ -84,17 +84,17 @@ void HeaderTemplateProvider::slotEditTemplate()
 void HeaderTemplateProvider::slotDeleteTemplate()
 {
   DefaultProvider::self()->deleteDocumentText( currentText() );
-  emit deleteHeaderText( currentText() );
+  Q_EMIT deleteHeaderText( currentText() );
 }
 
 void HeaderTemplateProvider::slotTemplateToDocument()
 {
   // qDebug () << "Moving template to document";
 
-  emit headerTextToDocument(currentText(), true);
+  Q_EMIT headerTextToDocument(currentText(), true);
 }
 
 void HeaderTemplateProvider::slotInsertTemplateToDocument()
 {
-    emit headerTextToDocument(currentText(), false);
+    Q_EMIT headerTextToDocument(currentText(), false);
 }
