@@ -19,7 +19,7 @@
 #include <QFile>
 #include <QSqlQuery>
 #include <QStringList>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 #include <QSqlError>
 #include <QDir>
@@ -33,8 +33,6 @@
 #include "doctype.h"
 #include "dbids.h"
 #include "defaultprovider.h"
-#include "archiveman.h"
-#include "documentsaverdb.h"
 #include "databasesettings.h"
 #include "stringutil.h"
 
@@ -108,15 +106,8 @@ KraftDB::KraftDB()
     :QObject (), mParent(nullptr),
       mSuccess( true ),
       EuroTag( QString::fromLatin1( "%EURO" ) ),
-      mInitDialog(nullptr),
-      _amountOfDocs(-1),
-      _amountOfArchs(-1),
-      _emitDBChangeSignal(true)
+      mInitDialog(nullptr)
 {
-    // Attention: Before setup assistant rewrite, dbConnect() was called here.
-    // Keep that in mind, maybe the auto connect to the DB now misses somewhere.
-    // dbConnect();
-    connect( &_timer, &QTimer::timeout, this, &KraftDB::slotCheckDocDatabaseChanged);
 
 }
 
@@ -186,15 +177,6 @@ bool KraftDB::dbConnect( const QString& driver, const QString& dbName,
     return mSuccess;
 }
 
-void KraftDB::enableTimerRefresh(bool runTimer)
-{
-    if (mSuccess && runTimer) {
-        _timer.start(10*1000);
-    } else {
-        _timer.stop();
-    }
-}
-
 KraftDB *KraftDB::self()
 {
     return mSelf;
@@ -228,7 +210,9 @@ int KraftDB::checkConnect( const QString& host, const QString& dbName,
     }
     int re = 0;
 
-    m_db.setConnectOptions("MYSQL_OPT_RECONNECT=1");
+    if (!isSqlite()) {
+        m_db.setConnectOptions("MYSQL_OPT_RECONNECT=1");
+    }
     m_db.open();
     if ( m_db.isOpenError() ) {
          qDebug () << "ERR opening the db: " << m_db.lastError().text() <<
@@ -349,14 +333,13 @@ SqlCommandList KraftDB::parseCommandFile( const QString& file )
             qDebug () << "FATAL: Could not open " << sqlFile;
         } else {
             QTextStream ts( &f );
-            ts.setCodec("UTF-8");
 
             QString allSql = ts.readAll(); //Not sure of this one!
             QStringList sqlList = allSql.split(";");
 
-            QRegExp reg( "\\s*(#|--)\\s*message:? ?(.*)\\s*\\n" );
-            QRegExp failreg( "\\s*(#|--)\\s*mayfail\\s*\\n" );
-            reg.setMinimal( true );
+            QRegularExpression reg( "\\s*(#|--)\\s*message:? ?(.*)\\s*\\n" );
+            QRegularExpression failreg( "\\s*(#|--)\\s*mayfail\\s*\\n" );
+            // reg.setMinimal( true ); FIXME Qt6 port
 
             QListIterator<QString> it(sqlList);
 
@@ -364,19 +347,19 @@ SqlCommandList KraftDB::parseCommandFile( const QString& file )
                 QString msg, command;
 
                 QString sqlFragment = it.next().trimmed();
-
-                int pos = reg.indexIn( sqlFragment.toLower(),  0 );
+                QRegularExpressionMatch match;
+                int pos = sqlFragment.toLower().indexOf(reg, 0, &match);
                 if ( pos > -1 ) {
-                    msg = reg.cap( 2 );
+                    msg = match.captured(2);
                     // qDebug() << "SQL-Commands-Parser: Msg: >" << msg << "<";
                 }
 
-                bool mayfail = false;
-                pos = failreg.indexIn( sqlFragment.toLower(), 0 );
+                bool mayfail{false};
+                pos = sqlFragment.toLower().indexOf(failreg, 0, &match);
                 if( pos > -1 ) {
                     mayfail = true;
                 }
-                bool clean = false;
+                bool clean{false};
                 while( ! clean ) {
                     if(  sqlFragment.startsWith("#") || sqlFragment.startsWith("--") ) {
                         // remove the comment line.
@@ -442,7 +425,6 @@ QList<MetaDocTypeAdd> KraftDB::parseMetaFile( int currentVersion )
             qWarning() << "FATAL: Could not open " << xmlFile;
         } else {
             QTextStream ts( &f );
-            ts.setCodec("UTF-8");
             parser.parse( &f );
         }
     } else {
@@ -481,9 +463,9 @@ int KraftDB::processSqlCommands( const SqlCommandList& commands )
         }
     }
 
-    foreach( SqlCommand cmd, commands ) {
+    for( SqlCommand cmd: commands ) {
         if( !cmd.message().isEmpty() ) {
-            emit statusMessage( cmd.message() );
+            Q_EMIT statusMessage( cmd.message() );
         }
 
         if( !cmd.command().isEmpty() ) {
@@ -501,7 +483,7 @@ int KraftDB::processSqlCommands( const SqlCommandList& commands )
                 qDebug () << "###### Failed SQL Command " << cmd.command() << ": " << err.text();
             }
             q.clear();
-            emit processedSqlCommand( res );
+            Q_EMIT processedSqlCommand( res );
 
         }
     }
@@ -565,7 +547,7 @@ QStringList KraftDB::wordList(const QString& selector, QMap<QString, QString> re
     query.bindValue(":cat", selector);
     query.exec();
     while ( query.next() ) {
-        re << StringUtil::replaceTagsInString(query.value(1).toString(), replaceMap);
+        re << KraftString::replaceTags(query.value(1).toString(), replaceMap);
     }
     re.sort();
     return re;
@@ -603,7 +585,7 @@ bool KraftDB::checkTableExistsSqlite(const QString& name, const QStringList& loo
 
     while( q.next() ) {
         const QString colName = q.value(1).toString();
-        qDebug() << "checking colum" << colName;
+        qDebug() << "checking column" << colName;
         cols.removeAll(colName);
     }
     return cols.isEmpty();
@@ -613,88 +595,5 @@ KraftDB::~KraftDB()
 {
 }
 
-void KraftDB::slotCheckDocDatabaseChanged()
-{
-    bool changed{false};
-    {
-        QSqlQuery q("SELECT count(*) FROM document");
 
-        q.exec();
-        QSqlError err = q.lastError();
-        if( err.isValid() ) {
-            qDebug() << "Error: " << err.text();
-            return;
-        }
-
-        if ( q.next() ) {
-            bool ok;
-            int cnt = q.value(0).toInt(&ok);
-
-            if (_amountOfDocs != -1 && cnt != _amountOfDocs ) {
-                qDebug() << "Docs from" << _amountOfDocs << "to" << cnt;
-                changed = true;
-            }
-            _amountOfDocs = cnt;
-        }
-    }
-    {
-        QSqlQuery qArch("SELECT count(*) FROM archdoc");
-
-        qArch.exec();
-        QSqlError err = qArch.lastError();
-        if( err.isValid() ) {
-            qDebug() << "Error: " << err.text();
-            return;
-        }
-
-        if ( qArch.next() ) {
-            bool ok;
-            int cnt = qArch.value(0).toInt(&ok);
-
-            if (_amountOfArchs != -1 && cnt != _amountOfArchs) {
-                qDebug() << "Arched docs from" << _amountOfArchs << "to" << cnt;
-                changed = true;
-            }
-            _amountOfArchs = cnt;
-        }
-    }
-    if (changed && _emitDBChangeSignal) emit docDatabaseChanged();
-}
-
-dbID KraftDB::archiveDocument( KraftDoc *docPtr )
-{
-    dbID archID = ArchiveMan::self()->archiveDocument( docPtr );
-
-    if (archID.isOk()) {
-        _emitDBChangeSignal = false; // block sending of the signal
-        slotCheckDocDatabaseChanged();
-        _emitDBChangeSignal = true;
-    }
-
-    return archID;
-}
-
-void KraftDB::loadDocument(const QString& id, KraftDoc *docPtr)
-{
-    DocumentSaverDB loader;
-
-    loader.load(id, docPtr);
-}
-
-bool KraftDB::saveDocument(KraftDoc *docPtr)
-{
-    bool res {false};
-    DocumentSaverDB saver;
-
-    if (docPtr) {
-        res  = saver.saveDocument(docPtr);
-        if (res) {
-            _emitDBChangeSignal = false; // block sending of the signal
-            slotCheckDocDatabaseChanged();
-            _emitDBChangeSignal = true;
-        }
-    }
-
-    return res;
-}
 
