@@ -18,11 +18,11 @@
 #ifndef KRAFTDB_H
 #define KRAFTDB_H
 
-#include <QtCore>
 #include <QSqlError>
 #include <QSqlDatabase>
 #include <QMap>
 #include <QDateTime>
+#include <QObject>
 
 #include "metaxmlparser.h"
 
@@ -35,36 +35,7 @@ class KraftDoc;
   *@author Klaas Freitag
   */
 
-class SqlCommand
-{
-public:
-  SqlCommand();
-  SqlCommand( const QString&, const QString&, bool );
-
-  QString message();
-  QString command();
-  bool    mayfail();
-
-private:
-  QString mSql;
-  QString mMessage;
-  bool    mMayFail;
-};
-
-class SqlCommandList: public QList<SqlCommand>
-{
-public:
-  SqlCommandList();
-
-  QList<MetaDocTypeAdd> metaAddDocTypeList() const;
-  void setMetaAddDocTypeList( QList<MetaDocTypeAdd> list );
-  void setNumber(int no);
-  int number();
-private:
-  QList<MetaDocTypeAdd> _docTypeMetaList;
-  int _number;
-};
-
+class SqlCommandList;
 
 class KraftDB : public QObject
 {
@@ -104,7 +75,7 @@ public:
   bool databaseExists();
 
   /*
-   * required and current schema versions. Must be equal for a healty
+   * required and current schema versions. Must be equal for a healthy
    * Kraft database. If currentSchemaVersion is smaller than requiredSchemaVersion,
    * the db needs an update.
    */
@@ -137,20 +108,9 @@ public:
 
   KraftDB();
 
-  dbID archiveDocument( KraftDoc *docPtr );
-
-  void loadDocument(const QString& id, KraftDoc *docPtr);
-  bool saveDocument(KraftDoc *docPtr);
-
-  void enableTimerRefresh(bool runTimer);
-
-private slots:
-  void slotCheckDocDatabaseChanged();
-
-signals:
+Q_SIGNALS:
   void statusMessage( const QString& );
   void processedSqlCommand( bool );
-  void docDatabaseChanged();
 
 private: // Private attributes
   void close();
@@ -168,14 +128,37 @@ private: // Private attributes
   QString mDatabaseName;
   DbInitDialog *mInitDialog;
   SetupAssistant *mSetupAssistant;
-  QTimer _timer;
+};
 
-  int _amountOfDocs, _amountOfArchs;
 
-  // if this is set to false, the slotCheckDatabaseChanged() can be called
-  // to update the members that hold the amount of docs, but the update signal
-  // is not sent out.
-  bool _emitDBChangeSignal;
+class SqlCommand
+{
+public:
+  SqlCommand();
+  SqlCommand( const QString&, const QString&, bool );
+
+  QString message();
+  QString command();
+  bool    mayfail();
+
+private:
+  QString mSql;
+  QString mMessage;
+  bool    mMayFail;
+};
+
+class SqlCommandList: public QList<SqlCommand>
+{
+public:
+  SqlCommandList();
+
+  QList<MetaDocTypeAdd> metaAddDocTypeList() const;
+  void setMetaAddDocTypeList( QList<MetaDocTypeAdd> list );
+  void setNumber(int no);
+  int number();
+private:
+  QList<MetaDocTypeAdd> _docTypeMetaList;
+  int _number;
 };
 
 #endif
