@@ -56,9 +56,7 @@ TreeItem::TreeItem(AbstractIndx *indx, TreeItem *parent)
 
 TreeItem::~TreeItem()
 {
-    foreach( TreeItem *i, childItems ) {
-        delete i;
-    }
+    qDeleteAll(childItems);
 }
 
 TreeItem* TreeItem::child(int row)
@@ -158,6 +156,7 @@ public:
 DateModel::DateModel(QObject *parent)
     :DocBaseModel(parent)
 {
+    setObjectName("Datemodel");
     rootItem = new TreeItem(0);
 }
 
@@ -227,7 +226,8 @@ QVariant DateModel::data(const QModelIndex &index, int role) const
     if( indx->type() == AbstractIndx::MonthType ) {
         // there might be a special column type
         if( col == 0 ) {
-            return QDate::shortMonthName(item->payload()->month());
+            QLocale l;
+            return l.monthName(item->payload()->month());
         } else if(col == Treestruct_Month) {
             return item->payload()->month();
         } else if(col == Treestruct_Year) {
@@ -249,7 +249,6 @@ QVariant DateModel::data(const QModelIndex &index, int role) const
         }
 #endif
     }
-
     if( indx->type() == AbstractIndx::DocumentType ) {
         DocDigest digest = item->payload()->digest();
         if( index.column() == Document_Id ) {
@@ -258,7 +257,7 @@ QVariant DateModel::data(const QModelIndex &index, int role) const
             return date.day();
         } else {
             return columnValueFromDigest( digest, index.column() );
-        }
+      }
     }
     return QVariant();
 }
@@ -308,8 +307,8 @@ QModelIndex DateModel::parent(const QModelIndex &index) const
 int DateModel::rowCount(const QModelIndex &parent) const
 {
     TreeItem *parentItem;
-     if (parent.column() > 0)
-         return 0;
+//     if (parent.column() > 0)
+//         return 0;
 
      if (!parent.isValid())
          parentItem = rootItem;
@@ -352,7 +351,7 @@ TreeItem *DateModel::findYearItem(int year)
     TreeItem *yearItem = NULL;
 
     QList<TreeItem*> yearitems = rootItem->children();
-    foreach( TreeItem *item, yearitems ) {
+    for( TreeItem *item: yearitems ) {
         AbstractIndx *indx = item->payload();
         if( indx->year() == year ) {
             yearItem = item;
@@ -369,7 +368,7 @@ TreeItem *DateModel::findMonthItem(int year, int month)
 
     if( yearItem ) {
         QList<TreeItem*> monthItems = yearItem->children();
-        foreach( TreeItem *item, monthItems ) {
+        for( TreeItem *item: monthItems ) {
             AbstractIndx *indx = static_cast<AbstractIndx*>(item->payload());
             if( indx->month() == month ) {
                 monthItem = item;
@@ -414,11 +413,46 @@ DocDigest DateModel::digest(const QModelIndex& indx) const
 
 void DateModel::removeAllData()
 {
-    // the destructor of the TreeItem removes the entire tree recursivly
+    // the destructor of the TreeItem removes the entire tree recursively
     delete rootItem;
     rootItem = new TreeItem(0);
 }
 
+void DateModel::appendNewDoc(const DocDigest& digest)
+{
+    int month = digest.rawDate().month();
+    int year = digest.rawDate().year();
+
+    TreeItem *yearItem = NULL;
+    TreeItem *monthItem = NULL;
+
+    yearItem = findYearItem( year );
+
+    if( !yearItem ) {
+        AbstractIndx *newIndx = new YearIndx(year);
+        yearItem = new TreeItem( newIndx, rootItem );
+    }
+
+    // ====
+    monthItem = findMonthItem( year, month );
+
+    if( !monthItem ) {
+        AbstractIndx *newIndx = new MonthIndx(year, month);
+        monthItem = new TreeItem( newIndx, yearItem);
+    }
+
+    QModelIndex yearIdx = index(yearItem->row(), 0 /* DocBaseModel::Treestruct_Year */, QModelIndex());
+    QModelIndex monthIdx = index(monthItem->row(), 0 /* DocBaseModel::Treestruct_Month */, yearIdx);
+
+    int r = rowCount(monthIdx);
+    beginInsertRows(monthIdx, r, r+1);
+
+    DocumentIndx *itemIndx = new DocumentIndx(digest);
+    TreeItem *newItem = new TreeItem( itemIndx, monthItem );
+    Q_UNUSED(newItem);
+    endInsertRows();
+}
+
 void DateModel::addData( const DocDigest& digest ) // DocumentIndx doc )
 {
     int month = digest.rawDate().month();
@@ -446,6 +480,39 @@ void DateModel::addData( const DocDigest& digest ) // DocumentIndx doc )
     TreeItem *newItem = new TreeItem( itemIndx, monthItem );
 
     Q_UNUSED(newItem);
-
 }
 
+void DateModel::updateData(const DocDigest& digest)
+{
+    int month = digest.rawDate().month();
+    int year = digest.rawDate().year();
+
+    TreeItem *monthItem = NULL;
+
+    // ====
+    monthItem = findMonthItem( year, month );
+
+    if (monthItem) {
+        int r = -1;
+        for (TreeItem *item : monthItem->children()) {
+            AbstractIndx *abstractindx = item->payload();
+
+            const DocDigest& d = abstractindx->digest();
+
+            if (d.uuid() == digest.uuid()) {
+                abstractindx->setDigest(digest);
+                r = item->row();
+                break;
+            }
+        }
+        if (r > -1) {
+            QModelIndex yearIdx = index(year, 0, QModelIndex());
+            QModelIndex monthIdx = index(month, 0, yearIdx);
+
+            QModelIndex rIdx = index(r, 0, monthIdx);
+            Q_EMIT dataChanged(rIdx, rIdx);
+        }
+    }
+
+
+}
