@@ -25,16 +25,13 @@
 #include <QMainWindow>
 #include <QUrl>
 
-#include <kcontacts/addressee.h>
-
 #include "docguardedptr.h"
 #include "katalogview.h"
-#include "dbids.h"
 #include "portalview.h"
 #include "reportgenerator.h"
+#include "myidentity.h"
 
 class KraftViewBase;
-class ArchDocDigest;
 class AddressProvider;
 class PrefsDialog;
 
@@ -47,13 +44,16 @@ class Portal : public QMainWindow
   friend class KraftView;
 
   public:
-    /** construtor of Portal, calls all init functions to create the application.
+    /** constructor of Portal, calls all init functions to create the application.
      */
     Portal( QWidget* parent = 0, QCommandLineParser *commandLineParser = 0, const char* name = 0);
 
     static QString textWrap(const QString& t, int width=40, int maxLines = -1 );
 
     QWidget* mainWidget();
+
+    void slotStartupChecks();
+
   protected:
     /** initializes the QActions of the application */
     void initActions();
@@ -61,7 +61,7 @@ class Portal : public QMainWindow
      */
     void initView();
     /** queryClose is called by KTMainWindow on each closeEvent of a window. Against the
-     * default implementation (only returns true), this calles saveModified() on the document object to ask if the document shall
+     * default implementation (only returns true), this calls saveModified() on the document object to ask if the document shall
      * be saved if Modified; on cancel the closeEvent is rejected.
      * @see KTMainWindow#queryClose
      * @see KTMainWindow#closeEvent
@@ -75,20 +75,19 @@ class Portal : public QMainWindow
      */
     virtual bool queryExit();
 
-
-  protected slots:
-    void slotStartupChecks();
-    void slotOpenArchivedDoc( const ArchDocDigest& );
-    void slotExportXRechnungArchivedDoc(const ArchDocDigest&);
+  protected Q_SLOTS:
     void slotXRechnungCurrentDocument();
 
-    void slotPrefsDialogFinished( int );
     void slotDocConverted(ReportFormat format, const QString& file,
                           const KContacts::Addressee& customerContact);
-    void slotDocConvertionFail(const QString& failString, const QString &details);
+    void slotDocConvertionFail(const QString &uuid, const QString& failString, const QString &details);
     void openInMailer(const QString& fileName, const KContacts::Addressee& contact);
 
-  public slots:
+    QString slotConvertToXML();
+
+  public Q_SLOTS:
+
+    void show();
 
     /** closes all open windows, then quits the application.
      */
@@ -111,25 +110,29 @@ class Portal : public QMainWindow
     void slotShowTemplates();
 
     void slotOpenKatalog(const QString& );
-    void slotOpenKatalog();
     void slotKatalogToXML(const QString&);
     void preferences();
     void slotNewDocument();
     void slotCopyCurrentDocument();
-    void slotCopyDocument( const QString& );
-    void slotOpenDocument( const QString& );
+    void slotCopyDocument(const QString& uuid);
     void slotOpenCurrentDocument();
+    void slotOpenDocument(const QString& ident);
+    void slotDoubleClicked();
 
     void slotViewCurrentDocument();
     void slotViewDocument( const QString& );
+    void slotChangeDocStatus();
+    void slotFinalizeDoc();
+    void slotOpenCurrentPDF();
+    void slotGenerateCurrentPDF();
 
     void slotFollowUpDocument();
-    void slotDocumentSelected( const DocDigest& );
-    void slotArchivedDocExecuted();
-    void slotArchivedDocSelected( const ArchDocDigest& );
-    void slotPrintCurrentDocument();
-    void slotPrintDocument( const QString&, const dbID& );
-    void slotViewClosed( bool, DocGuardedPtr );
+    void slotDocumentSelected( const QString& );
+    void slotPrintCurrentPDF();
+    void slotPrintPDF(const QString &uuid);
+    void slotGeneratePDF(const QString& uuid);
+
+    void slotViewClosed(bool, DocGuardedPtr , bool modified);
     void slotEditTagTemplates();
     void slotReconfigureDatabase();
     void slotAboutQt();
@@ -138,17 +141,18 @@ class Portal : public QMainWindow
 
     void busyCursor( bool );
     void slotMailDocument();
-    void slotOpenPdf( const QString& );
+    void slotOpenPDF(const QString& uuid);
 
     void slotReceivedMyAddress( const QString&, const KContacts::Addressee& );
 
   private:
     void createView( DocGuardedPtr );
     void createROView( DocGuardedPtr );
-    void savePdfInCustomerStructure(const QString& fileName);
 
     QScopedPointer<PortalView> m_portalView;
 
+    QString _currentSelectedUuid, _toMailFile;
+
     // QAction pointers to enable/disable actions
     QAction* _actFileQuit;
     QAction* _actEditCut;
@@ -159,20 +163,22 @@ class Portal : public QMainWindow
     QAction* _actHandbook;
     QAction* _actPreferences;
     QAction* _actReconfDb;
+    QAction* _actXmlConvert;
 
     QAction* _actNewDocument;
     QAction* _actCopyDocument;
-    QAction* _actOpenDocument;
+    QAction* _actEditDocument;
     QAction* _actViewDocument;
     QAction* _actFollowDocument;
-    QAction* _actPrintDocument;
-    QAction* _actMailDocument;
     QAction* _actXRechnung;
     QAction* _actEditTemplates;
 
-    QAction* _actOpenArchivedDocument;
-
-    QAction* _actViewFlosTemplates;
+    QAction* _actFinalizeDocument;
+    QAction* _actChangeDocStatus;
+    QAction* _actOpenDocumentPDF;
+    QAction* _actGeneratePDF;
+    QAction* _actPrintPDF;
+    QAction* _actMailPDF;
 
     QCommandLineParser *mCmdLineArgs;
 
@@ -180,12 +186,10 @@ class Portal : public QMainWindow
     QMap<KraftDoc*, KraftViewBase*> mViewMap;
 
     AddressProvider *mAddressProvider;
-    KContacts::Addressee myContact;
     PrefsDialog *_prefsDialog;
-    DocGuardedPtr _currentDoc;
 
     ReportGenerator _reportGenerator;
-
+    MyIdentity _myIdentity;
     bool _readOnlyMode;
 };
 
