@@ -29,6 +29,7 @@ class KatalogListView;
 class FloskelTemplate;
 class FlosTemplDialog;
 class QBoxLayout;
+class DocPosition;
 /**
   * The base class for Kraft katalog view.
 
@@ -41,7 +42,7 @@ class TemplKatalogView: public KatalogView
   Q_OBJECT
 
 public:
-  /** construtor of KraftApp, calls all init functions to create the application.
+  /** constructor of KraftApp, calls all init functions to create the application.
    */
   TemplKatalogView(QWidget* parent=0, const char* name=0);
   TemplKatalogView(const QString& katToShow, QWidget* parent=0, const char* name=0);
@@ -56,7 +57,7 @@ public:
 
 protected:
   Katalog* getKatalog( const QString& );
-  bool currentItemToDocPosition( DocPosition& );
+  bool currentItemToDocPosition(DocPosition&);
   CalcPartList currentItemsCalcParts();
 
   void saveWindowState( const QByteArray& arr );
@@ -65,7 +66,7 @@ protected:
   void saveWindowGeo( const QByteArray& arr );
   QByteArray windowGeo();
 
-public slots:
+public Q_SLOTS:
   /* Editing of templates -> open edit dialog */
   void slEditTemplate();
   void slNewTemplate();
