@@ -32,10 +32,63 @@ UnitManager* UnitManager::self()
 }
 
 UnitManager::UnitManager( )
+    : mFullTax( -1 ),
+      mReducedTax( -1 )
 {
 
 }
 
+#if 0
+void UnitManager::clearTaxCache()
+{
+  mFullTax = -1;
+  mReducedTax = -1;
+}
+#endif
+
+
+/* These tax related functions are just dropped here for the moment because they
+ * are pretty similar to the units in terms of reading from DB etc. Clear FIXME.
+ */
+
+double UnitManager::tax( const QDate& date )
+{
+  if ( mFullTax < 0 || date != mTaxDate )
+    readTaxes( date );
+  return mFullTax;
+}
+
+double UnitManager::reducedTax( const QDate& date )
+{
+  if ( mReducedTax < 0 || date != mTaxDate )
+    readTaxes( date );
+  return mReducedTax;
+}
+
+bool UnitManager::readTaxes( const QDate& date )
+{
+  QString sql;
+  QSqlQuery q;
+  sql = "SELECT fullTax, reducedTax, startDate FROM taxes ";
+  sql += "WHERE startDate <= :date ORDER BY startDate DESC LIMIT 1";
+
+  q.prepare( sql );
+  QString dateStr = date.toString( "yyyy-MM-dd" );
+  // qDebug () << "** Datestring: " << dateStr;
+  q.bindValue( ":date", dateStr );
+  q.exec();
+
+  if ( q.next() ) {
+    mFullTax    = q.value( 0 ).toDouble();
+    mReducedTax = q.value( 1 ).toDouble();
+    mTaxDate = date;
+    // qDebug () << "* Taxes: " << mFullTax << "/" << mReducedTax << " from " << q.value( 2 ).toDate();
+  }
+  return ( mFullTax > 0 && mReducedTax > 0 );
+}
+
+/* ============================================================================================= */
+
 void UnitManager::load()
 {
   QSqlQuery q( "SELECT unitID, unitShort, unitLong, unitPluShort, unitPluLong, ec20 FROM units");
@@ -59,7 +112,7 @@ int UnitManager::nextFreeId()
     if( mUnits.size() == 0 ) {
         load();
     }
-    foreach( Einheit u, mUnits ) {
+    for( Einheit u: mUnits ) {
         if( u.id() > id ) {
             id = u.id();
         }
@@ -72,7 +125,7 @@ QStringList UnitManager::allUnits()
   QStringList list;
 
   if(mUnits.size() == 0 ) load();
-  foreach( Einheit e, mUnits ) {
+  for( Einheit e: mUnits ) {
     QString uSing = e.einheitSingular();
     if( !uSing.isEmpty())
       list << uSing;
@@ -92,22 +145,34 @@ Einheit UnitManager::getUnit( int id )
 {
   if( mUnits.size() == 0 ) load();
 
-  // qDebug() << "Searching unit ID " << id;
-  foreach( Einheit e, mUnits ) {
+  // qDebug() << "Searching unit ID " << id << endl;
+  for( Einheit e: mUnits ) {
     if( e.id() == id ) return e;
   }
   return Einheit();
 }
 
+Einheit UnitManager::getUnit(const QString& singularUnit)
+{
+    if( mUnits.size() == 0 ) load();
+
+    // qDebug() << "Searching unit ID " << id << endl;
+    for( Einheit e: mUnits ) {
+      if( e.einheitSingular() == singularUnit)
+          return e;
+    }
+    return Einheit();
+}
+
 int UnitManager::getUnitIDSingular( const QString& einheitStr )
 {
   if( mUnits.size() == 0 ) load();
 
-  foreach( Einheit tmp, mUnits ) {
+  for( Einheit tmp: mUnits ) {
 
     if( tmp.einheitSingular() == einheitStr ||
         tmp.einheitPlural()   == einheitStr ) {
-      // qDebug() << "Thats it, returning " << tmp.id();
+      // qDebug() << "That's it, returning " << tmp.id();
       return tmp.id();
     }
   }
@@ -121,7 +186,7 @@ QString UnitManager::getECE20(const QString& einheitStr)
     for( Einheit tmp: mUnits ) {
       if( tmp.einheitSingular() == einheitStr ||
           tmp.einheitPlural()   == einheitStr ) {
-        // qDebug() << "Thats it, returning " << tmp.id();
+        // qDebug() << "That's it, returning " << tmp.id();
         return tmp.ec20();
       }
     }
