@@ -3,6 +3,8 @@
 #include <QSql>
 #include <QSqlDatabase>
 #include <QSqlQuery>
+#include <QStandardPaths>
+#include <QSettings>
 
 #include "defaultprovider.h"
 
@@ -20,7 +22,7 @@ void createTestFile( const QString& testFile, const QString& content = QString()
     QVERIFY (file.open(QIODevice::WriteOnly));
     {
         QTextStream stream(&file);
-        stream << c << endl;
+        stream << c << Qt::endl;
     }
 }
 
@@ -32,13 +34,13 @@ class T_Defaultprovider: public QObject {
 private:
     QString _systemDir;
 
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         const QStringList dirs = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation);
         const QString home = QDir::homePath();
         const QString appName = qAppName();
-        const QString testDir = QString("%1/.local/share/%2").arg(home).arg(appName);
+        const QString testDir = QString("%1/.local/share/%2").arg(home, appName);
 
         int indx = dirs.indexOf(testDir);
         QVERIFY(indx > -1);
@@ -145,12 +147,54 @@ private slots:
             const QString noExistFile2 = DefaultProvider::self()->locateFile("nomydir/kraftfile");
             QVERIFY(noExistFile2.isEmpty());
 
-            QVERIFY(fi.dir().removeRecursively());
-
+            QVERIFY(td.removeRecursively());
         } else {
             qDebug() << "Skipped relative path test, directory share exists.";
         }
     }
+
+    void testKraftV2Dirs()
+    {
+        QTemporaryDir dir;
+        dir.setAutoRemove(true);
+
+        const QString p = dir.path();
+        const QString base = DefaultProvider::self()->createV2BaseDir(p);
+        QVERIFY(base.startsWith(p));
+        QVERIFY(base.length() == p.length()+6); // it has the a uuid partikel appended
+
+        QString pRoot = DefaultProvider::self()->kraftV2Dir(DefaultProvider::KraftV2Dir::Root);
+        const QString pNumC = DefaultProvider::self()->kraftV2Dir(DefaultProvider::KraftV2Dir::NumberCycles);
+        const QString pXmlD = DefaultProvider::self()->kraftV2Dir(DefaultProvider::KraftV2Dir::XmlDocs);
+        const QString pOwnI = DefaultProvider::self()->kraftV2Dir(DefaultProvider::KraftV2Dir::OwnIdentity);
+        QCOMPARE(base, pOwnI);
+        QCOMPARE(base, pRoot);
+        QCOMPARE(base + "/numbercycles", pNumC);
+        QCOMPARE(base + "/xmldoc", pXmlD);
+    }
+
+    void createNewBaseDir()
+    {
+        QTemporaryDir _dir;
+        _dir.setAutoRemove(true);
+
+        const QString p{ _dir.path() + "/v2"};
+        QDir d{p};
+        QVERIFY(d.mkpath(p));
+
+        const QString newDir = DefaultProvider::self()->createV2BaseDir(p);
+        QVERIFY(newDir.startsWith(p));
+        qDebug() << "New directory:" << newDir;
+        bool ok = DefaultProvider::self()->switchToV2BaseDir(newDir);
+        QVERIFY(ok);
+
+        QSettings settings(p + "/Kraft2.ini", QSettings::NativeFormat);
+        const QString frag = settings.value("Global/currentDir", "NOT_FOUND").toString();
+        QVERIFY(frag != "NOT_FOUND");
+        QFileInfo fi{p, frag};
+        QVERIFY(fi.exists());
+        QVERIFY(fi.isDir());
+    }
 };
 
 QTEST_MAIN(T_Defaultprovider)
